import { Button } from "@/components/ui/button"
import { Card, CardContent } from "@/components/ui/card"
import { Input } from "@/components/ui/input"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Badge } from "@/components/ui/badge"
import { MapPin, Calendar, DollarSign, Search } from "lucide-react"
import Link from "next/link"

export default function TasksPage() {
  // Моковые данные для примера
  const tasks = [
    {
      id: 1,
      title: "Помыть окна в квартире",
      category: "Бытовые услуги",
      subcategory: "Мытье окон",
      location: "Москва, ул. Ленина, 10",
      date: "25 мая 2025",
      budget: "2000",
      description: "Необходимо помыть 5 окон в квартире. Окна стандартные, двухстворчатые.",
    },
    {
      id: 2,
      title: "Мытье окон в офисе",
      category: "Бытовые услуги",
      subcategory: "Мытье окон",
      location: "Москва, Пресненская наб., 12",
      date: "27 мая 2025",
      budget: "5000",
      description: "Требуется помыть 10 панорамных окон в офисе на 15 этаже бизнес-центра.",
    },
    {
      id: 3,
      title: "Уборка квартиры после ремонта",
      category: "Бытовые услуги",
      subcategory: "Уборка",
      location: "Москва, ул. Арбат, 24",
      date: "30 мая 2025",
      budget: "4000",
      description: "Генеральная уборка двухкомнатной квартиры после ремонта, включая мытье окон.",
    },
  ]

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-2xl font-bold">Найти задания</h1>
        <p className="text-muted-foreground">Выберите задание и предложите свои услуги</p>
      </div>

      <div className="grid gap-6 md:grid-cols-[300px_1fr]">
        <div className="space-y-6">
          <Card>
            <CardContent className="p-4">
              <div className="space-y-4">
                <div>
                  <label className="mb-2 block text-sm font-medium">Поиск</label>
                  <div className="relative">
                    <Search className="absolute left-2.5 top-2.5 h-4 w-4 text-muted-foreground" />
                    <Input placeholder="Поиск заданий..." className="pl-8" />
                  </div>
                </div>

                <div>
                  <label className="mb-2 block text-sm font-medium">Категория</label>
                  <Select>
                    <SelectTrigger>
                      <SelectValue placeholder="Все категории" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">Все категории</SelectItem>
                      <SelectItem value="house">Бытовые услуги</SelectItem>
                      <SelectItem value="business">Бизнес услуги</SelectItem>
                      <SelectItem value="transport">Перевозки</SelectItem>
                      <SelectItem value="shopping">Покупки</SelectItem>
                      <SelectItem value="repair">Ремонт техники</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div>
                  <label className="mb-2 block text-sm font-medium">Местоположение</label>
                  <Select>
                    <SelectTrigger>
                      <SelectValue placeholder="Все города" />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value="all">Все города</SelectItem>
                      <SelectItem value="moscow">Москва</SelectItem>
                      <SelectItem value="spb">Санкт-Петербург</SelectItem>
                      <SelectItem value="ekb">Екатеринбург</SelectItem>
                      <SelectItem value="nsk">Новосибирск</SelectItem>
                    </SelectContent>
                  </Select>
                </div>

                <div>
                  <label className="mb-2 block text-sm font-medium">Бюджет</label>
                  <div className="flex items-center gap-2">
                    <Input type="number" placeholder="От" />
                    <span>-</span>
                    <Input type="number" placeholder="До" />
                  </div>
                </div>

                <Button className="w-full">Применить фильтры</Button>
              </div>
            </CardContent>
          </Card>
        </div>

        <div className="space-y-4">
          <Tabs defaultValue="all">
            <TabsList>
              <TabsTrigger value="all">Все задания</TabsTrigger>
              <TabsTrigger value="new">Новые</TabsTrigger>
              <TabsTrigger value="inprogress">В работе</TabsTrigger>
              <TabsTrigger value="completed">Выполненные</TabsTrigger>
            </TabsList>

            <TabsContent value="all" className="mt-4">
              <div className="space-y-4">
                {tasks.map((task) => (
                  <Card key={task.id}>
                    <CardContent className="p-6">
                      <div className="flex flex-col gap-4 md:flex-row md:items-start md:justify-between">
                        <div className="space-y-2">
                          <div className="flex items-center gap-2">
                            <Badge variant="outline">{task.subcategory}</Badge>
                            <span className="text-sm text-muted-foreground">ID: {task.id}</span>
                          </div>
                          <h3 className="text-xl font-semibold">
                            <Link href={`/tasks/${task.id}`} className="hover:underline">
                              {task.title}
                            </Link>
                          </h3>
                          <p className="text-sm text-muted-foreground">{task.description}</p>
                          <div className="flex flex-wrap gap-4 pt-2">
                            <div className="flex items-center text-sm text-muted-foreground">
                              <MapPin className="mr-1 h-4 w-4" />
                              {task.location}
                            </div>
                            <div className="flex items-center text-sm text-muted-foreground">
                              <Calendar className="mr-1 h-4 w-4" />
                              {task.date}
                            </div>
                            <div className="flex items-center text-sm font-medium">
                              <DollarSign className="mr-1 h-4 w-4" />
                              {task.budget} ₽
                            </div>
                          </div>
                        </div>
                        <div className="flex shrink-0 flex-col gap-2">
                          <Button asChild>
                            <Link href={`/tasks/${task.id}`}>Откликнуться</Link>
                          </Button>
                          <Button variant="outline" size="sm">
                            Сохранить
                          </Button>
                        </div>
                      </div>
                    </CardContent>
                  </Card>
                ))}
              </div>
            </TabsContent>

            <TabsContent value="new">
              <div className="flex h-40 items-center justify-center rounded-md border border-dashed">
                <p className="text-center text-muted-foreground">Нет новых заданий</p>
              </div>
            </TabsContent>

            <TabsContent value="inprogress">
              <div className="flex h-40 items-center justify-center rounded-md border border-dashed">
                <p className="text-center text-muted-foreground">Нет заданий в работе</p>
              </div>
            </TabsContent>

            <TabsContent value="completed">
              <div className="flex h-40 items-center justify-center rounded-md border border-dashed">
                <p className="text-center text-muted-foreground">Нет выполненных заданий</p>
              </div>
            </TabsContent>
          </Tabs>
        </div>
      </div>
    </div>
  )
}
